@@ -13,27 +13,17 @@
 #  pragma ANSI_strict reset
 # endif
 
-extern "C" BOOL WINAPI DllMain ( HINSTANCE hInst, DWORD wDataSeg, LPVOID lpvReserved );
-
-# ifdef BOOST_MSVC
-extern "C" void structured_exception_translator(unsigned int, EXCEPTION_POINTERS*)
+# ifdef _MSC_VER
+#  pragma warning(push)
+#  pragma warning(disable:4297)
+extern "C" void straight_to_debugger(unsigned int, EXCEPTION_POINTERS*)
 {
     throw;
 }
+extern "C" void (*old_translator)(unsigned, EXCEPTION_POINTERS*)
+         = _set_se_translator(straight_to_debugger);
+#  pragma warning(pop)
 # endif
 
-BOOL WINAPI DllMain(
-    HINSTANCE,  //hDllInst
-    DWORD fdwReason,
-    LPVOID  // lpvReserved
-    )
-{
-# ifdef BOOST_MSVC
-    _set_se_translator(structured_exception_translator);
-# endif
-    (void)fdwReason; // warning suppression.
-
-    return 1;
-}
 #endif // _WIN32
 
